@@ -2,12 +2,6 @@
 #' @import twc
 twc::crop_data
 
-#' @export
-twc::csi
-
-#' @export
-twc::far
-
 #' @export
 twc::fldmean
 
@@ -17,15 +11,9 @@ twc::infoNC
 #' @export
 twc::muldpm
 
-#' @export
-twc::nse
-
 #' @export
 twc::pRecipe_masks
 
-#' @export
-twc::pod
-
 #' @export
 twc::remap
 
